@@ -12,15 +12,12 @@ var cl *client.TRPClient
 
 //export StartClientByVerifyKey
 func StartClientByVerifyKey(serverAddr, verifyKey, connType, proxyUrl *C.char) int {
-	logs.SetLogger("store")
+	_ = logs.SetLogger("store")
 	if cl != nil {
 		cl.Close()
 	}
 	cl = client.NewRPClient(C.GoString(serverAddr), C.GoString(verifyKey), C.GoString(connType), C.GoString(proxyUrl), nil, 60)
-	go func() {
-		cl.Start()
-		return
-	}()
+	cl.Start()
 	return 1
 }
 
